from django.db import models

# Create your models here.

from django.conf import settings
from uuid import uuid1
from django.utils import encoding

def UserDirectoryPath(instance, filename):
    # file will be uploaded to MEDIA_ROOT/sifrovacka_<id>/<filename>
    return 'sifrovacka_{0}/stage{1}/{2}'.format(instance.sifrovacka_id,
            instance.stage_number,
            encoding.smart_str(filename, encoding='utf-8', strings_only = True))

class Sifrovacka(models.Model):
    '''
    model which describes sifrovacka
    '''
    sifrovacka_name = models.CharField(max_length=200)
    #pub_date = models.DateField()
    pub_date = models.DateTimeField('date published')
    startdate_sifrovacka = models.DateField()
    enddate_sifrovacka = models.DateField()

    def __str__(self):
        return self.sifrovacka_name


class Stages(models.Model):
    '''
    model which describes how many stages are in particular sifrovacka
    '''
    sifrovacka = models.ForeignKey(Sifrovacka, on_delete=models.CASCADE)
    stage_number = models.IntegerField()
    stage_name = models.CharField(max_length=80)
    stage_description = models.CharField(max_length=500)
    stage_passphrase = models.CharField(max_length=30,
                       default='hesl0Sifrovacka')
    stage_img = models.ImageField(blank=True, upload_to=UserDirectoryPath)
    stage_urlhash = models.CharField(max_length=32, default=uuid1().hex)

#    if not stage_name_text models:
#        stage_name = getattr(Stages, sifrovacka_name)
#            "-" + getattr(Stages, stage_number))
#    else:
#        stage_name = stage_name_text
#    votes = models.IntegerField(default=0)
#    startdate_stages = models.DateField()
#    enddate_stages= models.DateField()

    def __str__(self):
        return str(self.sifrovacka) + " - Stage " + str(self.stage_number)


    class Meta:
        unique_together = [['stage_number', 'sifrovacka']]

class Participants(models.Model):
    '''
    table which connects sifrovacka with users who participate
    '''
    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete = models.CASCADE)
    sifrovacka = models.ForeignKey(Sifrovacka, on_delete = models.CASCADE)
    #at_stage = models.IntegerField(default=1)
    at_stage = models.CharField(max_length=32,default='xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx')
    inactive = models.BooleanField(default = False)

    def __str__(self):
        return str(self.user) + " - " + str(self.sifrovacka)


    class Meta:
        unique_together = [['user', 'sifrovacka']]

